@@ -10,11 +10,13 @@
 
 #include "marble_export.h"
 
-namespace Ui {
+namespace Ui
+{
 class MovieCaptureDialog;
 }
 
-namespace Marble {
+namespace Marble
+{
 
 class MarbleWidget;
 
@@ -38,8 +40,8 @@ Q_SIGNALS:
     void started();
 
 private:
-    Ui::MovieCaptureDialog *ui;
-    MovieCapture *m_recorder;
+    Ui::MovieCaptureDialog *const ui;
+    MovieCapture *const m_recorder;
 };
 
 } // namespace Marble
