@@ -13,11 +13,11 @@
 #define MARBLE_PLACEMARKLAYOUT_H
 
 #include <QHash>
+#include <QList>
+#include <QMap>
+#include <QPointer>
 #include <QRect>
 #include <QSet>
-#include <QMap>
-#include <QVector>
-#include <QPointer>
 
 #include "GeoDataPlacemark.h"
 #include <GeoDataStyle.h>
@@ -27,7 +27,6 @@ class QItemSelectionModel;
 class QPoint;
 class QModelIndex;
 
-
 namespace Marble
 {
 
@@ -44,21 +43,19 @@ class StyleBuilder;
  * Layouts the place marks with a passed QPainter.
  */
 
-
-
 class PlacemarkLayout : public QObject
 {
     Q_OBJECT
 
- public:
+public:
     /**
      * Creates a new place mark layout.
      */
-    PlacemarkLayout( QAbstractItemModel  *placemarkModel,
-                     QItemSelectionModel *selectionModel,
-                     MarbleClock *clock,
-                     const StyleBuilder* styleBuilder,
-                     QObject *parent = nullptr );
+    PlacemarkLayout(QAbstractItemModel *placemarkModel,
+                    QItemSelectionModel *selectionModel,
+                    MarbleClock *clock,
+                    const StyleBuilder *styleBuilder,
+                    QObject *parent = nullptr);
 
     /**
      * Destroys the place mark painter.
@@ -68,12 +65,12 @@ class PlacemarkLayout : public QObject
     /**
      * @reimp
      */
-    QVector<VisiblePlacemark *> generateLayout(const ViewportParams *viewport , int tileLevel);
+    QList<VisiblePlacemark *> generateLayout(const ViewportParams *viewport, int tileLevel);
 
     /**
      * Returns a list of model indexes that are at position @p pos.
      */
-    QVector<const GeoDataFeature *> whichPlacemarkAt( const QPoint &pos );
+    QList<const GeoDataFeature *> whichPlacemarkAt(const QPoint &pos);
 
     QString runtimeTrace() const;
 
@@ -81,27 +78,27 @@ class PlacemarkLayout : public QObject
 
     bool hasPlacemarkAt(const QPoint &pos);
 
- public Q_SLOTS:
+public Q_SLOTS:
     // earth
-    void setShowPlaces( bool show );
-    void setShowCities( bool show );
-    void setShowTerrain( bool show );
-    void setShowOtherPlaces( bool show );
+    void setShowPlaces(bool show);
+    void setShowCities(bool show);
+    void setShowTerrain(bool show);
+    void setShowOtherPlaces(bool show);
 
     // other planets
-    void setShowLandingSites( bool show );
-    void setShowCraters( bool show );
-    void setShowMaria( bool show );
+    void setShowLandingSites(bool show);
+    void setShowCraters(bool show);
+    void setShowMaria(bool show);
 
     void requestStyleReset();
-    void addPlacemarks( const QModelIndex& index, int first, int last );
-    void removePlacemarks( const QModelIndex& index, int first, int last );
+    void addPlacemarks(const QModelIndex &index, int first, int last);
+    void removePlacemarks(const QModelIndex &index, int first, int last);
     void resetCacheData();
 
- Q_SIGNALS:
+Q_SIGNALS:
     void repaintNeeded();
 
- private:
+private:
     /**
      * Returns a the maximum height of all possible labels.
      * WARNING: This is a really slow method as it traverses all placemarks
@@ -115,36 +112,34 @@ class PlacemarkLayout : public QObject
     void clearCache();
 
     static QSet<TileId> visibleTiles(const ViewportParams &viewport, int tileLevel);
-    bool layoutPlacemark(const GeoDataPlacemark *placemark, const GeoDataCoordinates &coordinates, qreal x, qreal y, bool selected );
+    bool layoutPlacemark(const GeoDataPlacemark *placemark, const GeoDataCoordinates &coordinates, qreal x, qreal y, bool selected);
 
     /**
      * Returns the coordinates at which an icon should be drawn for the @p placemark.
      * @p ok is set to true if the coordinates are valid and should be used for drawing,
      * it is set to false otherwise.
      */
-    GeoDataCoordinates placemarkIconCoordinates( const GeoDataPlacemark *placemark ) const;
+    GeoDataCoordinates placemarkIconCoordinates(const GeoDataPlacemark *placemark) const;
 
-    QRectF  roomForLabel(const GeoDataStyle::ConstPtr &style,
-                         const qreal x, const qreal y,
-                         const QString &labelText , const VisiblePlacemark *placemark) const;
-    bool    hasRoomForPixmap(const qreal y, const VisiblePlacemark *placemark) const;
+    QRectF roomForLabel(const GeoDataStyle::ConstPtr &style, const qreal x, const qreal y, const QString &labelText, const VisiblePlacemark *placemark) const;
+    bool hasRoomForPixmap(const qreal y, const VisiblePlacemark *placemark) const;
 
-    bool    placemarksOnScreenLimit( const QSize &screenSize ) const;
+    bool placemarksOnScreenLimit(const QSize &screenSize) const;
 
- private:
-    Q_DISABLE_COPY( PlacemarkLayout )
-    QAbstractItemModel*  m_placemarkModel;
+private:
+    Q_DISABLE_COPY(PlacemarkLayout)
+    QAbstractItemModel *m_placemarkModel;
     QItemSelectionModel *const m_selectionModel;
     MarbleClock *const m_clock;
 
-    QVector<VisiblePlacemark*> m_paintOrder;
+    QList<VisiblePlacemark *> m_paintOrder;
     QString m_runtimeTrace;
     int m_labelArea;
-    QHash<const GeoDataPlacemark*, VisiblePlacemark*> m_visiblePlacemarks;
-    QVector< QVector< VisiblePlacemark* > >  m_rowsection;
+    QHash<const GeoDataPlacemark *, VisiblePlacemark *> m_visiblePlacemarks;
+    QList<QList<VisiblePlacemark *>> m_rowsection;
 
     /// map providing the list of placemark belonging in TileId as key
-    QMap<TileId, QList<const GeoDataPlacemark*> > m_placemarkCache;
+    QMap<TileId, QList<const GeoDataPlacemark *>> m_placemarkCache;
     QSet<qint64> m_osmIds;
 
     const QSet<GeoDataPlacemark::GeoDataVisualCategory> m_acceptedVisualCategories;
@@ -160,9 +155,9 @@ class PlacemarkLayout : public QObject
     bool m_showCraters;
     bool m_showMaria;
 
-    int     m_maxLabelHeight;
-    bool    m_styleResetRequested;
-    const StyleBuilder* m_styleBuilder;
+    int m_maxLabelHeight;
+    bool m_styleResetRequested;
+    const StyleBuilder *m_styleBuilder;
     // Referencing these properties by value
     // instead of using a more fragile pointer
     bool m_lastPlacemarkAvailable;
