@@ -14,38 +14,36 @@ namespace Marble
 
 class GeoDataMultiTrackPrivate : public GeoDataGeometryPrivate
 {
-  public:
-    GeoDataMultiTrackPrivate()
-    {
-    }
+public:
+    GeoDataMultiTrackPrivate() = default;
 
     ~GeoDataMultiTrackPrivate() override
     {
         qDeleteAll(m_vector);
     }
 
-    GeoDataMultiTrackPrivate& operator=( const GeoDataMultiTrackPrivate &other)
+    GeoDataMultiTrackPrivate &operator=(const GeoDataMultiTrackPrivate &other)
     {
-        GeoDataGeometryPrivate::operator=( other );
+        GeoDataGeometryPrivate::operator=(other);
 
-        qDeleteAll( m_vector );
+        qDeleteAll(m_vector);
         m_vector.clear();
 
         m_vector.reserve(other.m_vector.size());
-        for( GeoDataTrack *track: other.m_vector ) {
-            m_vector.append( new GeoDataTrack( *track ) );
+        for (GeoDataTrack *track : other.m_vector) {
+            m_vector.append(new GeoDataTrack(*track));
         }
         return *this;
     }
 
     GeoDataGeometryPrivate *copy() const override
-    { 
-         GeoDataMultiTrackPrivate* copy = new GeoDataMultiTrackPrivate;
+    {
+        auto *copy = new GeoDataMultiTrackPrivate;
         *copy = *this;
         return copy;
     }
 
-    QVector<GeoDataTrack*>  m_vector;
+    QList<GeoDataTrack *> m_vector;
 };
 
 } // namespace Marble
