@@ -10,43 +10,44 @@
 #include "GeoDataObject.h"
 #include "MarbleGlobal.h"
 
-namespace Marble {
+namespace Marble
+{
 
 class GeoDataScalePrivate;
 
 /**
  */
-class GEODATA_EXPORT GeoDataScale: public GeoDataObject
+class GEODATA_EXPORT GeoDataScale : public GeoDataObject
 {
 public:
     GeoDataScale();
 
-    GeoDataScale( const GeoDataScale &other );
+    GeoDataScale(const GeoDataScale &other);
 
-    GeoDataScale& operator=( const GeoDataScale &other );
+    GeoDataScale &operator=(const GeoDataScale &other);
 
-    bool operator==( const GeoDataScale &other ) const;
-    bool operator!=( const GeoDataScale &other ) const;
+    bool operator==(const GeoDataScale &other) const;
+    bool operator!=(const GeoDataScale &other) const;
 
     ~GeoDataScale() override;
 
     /** Provides type information for downcasting a GeoNode */
-    const char* nodeType() const override;
+    const char *nodeType() const override;
 
     double x() const;
 
-    void setX( double x );
+    void setX(double x);
 
     double y() const;
 
-    void setY( double y );
+    void setY(double y);
 
     double z() const;
 
-    void setZ( double z);
+    void setZ(double z);
 
 private:
-    GeoDataScalePrivate* const d;
+    GeoDataScalePrivate *const d;
 };
 
 }
