@@ -13,24 +13,25 @@
 
 #include <QPixmap>
 
-namespace Marble {
+namespace Marble
+{
 
 class GeoDataScreenOverlay;
 
 class MARBLE_EXPORT ScreenOverlayGraphicsItem : public ScreenGraphicsItem
 {
 public:
-    explicit ScreenOverlayGraphicsItem( const GeoDataScreenOverlay *screenOverlay );
+    explicit ScreenOverlayGraphicsItem(const GeoDataScreenOverlay *screenOverlay);
 
-    const GeoDataScreenOverlay* screenOverlay() const;
+    const GeoDataScreenOverlay *screenOverlay() const;
 
-    void setProjection( const ViewportParams *viewport ) override;
+    void setProjection(const ViewportParams *viewport) override;
 
 protected:
-    void paint( QPainter* painter ) override;
+    void paint(QPainter *painter) override;
 
 private:
-    static qreal pixelValue( GeoDataVec2::Unit unit, qreal screenSize, qreal imageSize, qreal value );
+    static qreal pixelValue(GeoDataVec2::Unit unit, qreal screenSize, qreal imageSize, qreal value);
 
     const GeoDataScreenOverlay *m_screenOverlay;
 
