@@ -16,15 +16,15 @@ namespace dgml
 {
 DGML_DEFINE_TAG_HANDLER(InstallMap)
 
-GeoNode* DgmlInstallMapTagHandler::parse(GeoParser& parser) const
+GeoNode *DgmlInstallMapTagHandler::parse(GeoParser &parser) const
 {
     // Check whether the tag is valid
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(dgmlTag_InstallMap)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(dgmlTag_InstallMap)));
 
     // Checking for parent item
     GeoStackItem parentItem = parser.parentElement();
     if (parentItem.represents(dgmlTag_Texture) || parentItem.represents(dgmlTag_Vectortile))
-        parentItem.nodeAs<GeoSceneTileDataset>()->setInstallMap( parser.readElementText().trimmed() );
+        parentItem.nodeAs<GeoSceneTileDataset>()->setInstallMap(parser.readElementText().trimmed());
 
     return nullptr;
 }
