@@ -8,28 +8,28 @@
 
 #include "MarbleDebug.h"
 
+#include "GeoDataIconStyle.h"
+#include "GeoDataStyle.h"
+#include "GeoParser.h"
 #include "KmlElementDictionary.h"
 #include "KmlObjectTagHandler.h"
-#include "GeoDataStyle.h"
-#include "GeoDataIconStyle.h"
-#include "GeoParser.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( IconStyle )
+KML_DEFINE_TAG_HANDLER(IconStyle)
 
-GeoNode* KmlIconStyleTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlIconStyleTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_IconStyle)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_IconStyle)));
 
     GeoStackItem parentItem = parser.parentElement();
-    
-    if ( parentItem.represents( kmlTag_Style ) ) {
+
+    if (parentItem.represents(kmlTag_Style)) {
         GeoDataIconStyle style;
-        KmlObjectTagHandler::parseIdentifiers( parser, &style );
-        parentItem.nodeAs<GeoDataStyle>()->setIconStyle( style );
+        KmlObjectTagHandler::parseIdentifiers(parser, &style);
+        parentItem.nodeAs<GeoDataStyle>()->setIconStyle(style);
         return &parentItem.nodeAs<GeoDataStyle>()->iconStyle();
     }
     return nullptr;
