@@ -7,26 +7,26 @@
 
 #include "MarbleDebug.h"
 
-#include "KmlElementDictionary.h"
 #include "GeoDataLod.h"
 #include "GeoParser.h"
+#include "KmlElementDictionary.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( minFadeExtent )
+KML_DEFINE_TAG_HANDLER(minFadeExtent)
 
-GeoNode* KmlminFadeExtentTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlminFadeExtentTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_minFadeExtent)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_minFadeExtent)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if( parentItem.represents( kmlTag_Lod ) ) {
+    if (parentItem.represents(kmlTag_Lod)) {
         float minFadeExtent = parser.readElementText().trimmed().toFloat();
 
-        parentItem.nodeAs<GeoDataLod>()->setMinFadeExtent( minFadeExtent );
+        parentItem.nodeAs<GeoDataLod>()->setMinFadeExtent(minFadeExtent);
     }
 
     return nullptr;
