@@ -18,21 +18,21 @@ namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( SimpleData )
+KML_DEFINE_TAG_HANDLER(SimpleData)
 
-GeoNode* KmlSimpleDataTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlSimpleDataTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_SimpleData)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_SimpleData)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if ( parentItem.represents( kmlTag_SchemaData ) ) {
+    if (parentItem.represents(kmlTag_SchemaData)) {
         GeoDataSimpleData simpleData;
-        QString name = parser.attribute( "name" ).trimmed();
+        QString name = parser.attribute("name").trimmed();
         QString data = parser.readElementText().trimmed();
-        simpleData.setName( name );
-        simpleData.setData( data );
-        parentItem.nodeAs<GeoDataSchemaData>()->addSimpleData( simpleData );
+        simpleData.setName(name);
+        simpleData.setData(data);
+        parentItem.nodeAs<GeoDataSchemaData>()->addSimpleData(simpleData);
     }
     return nullptr;
 }
