@@ -7,10 +7,10 @@
 
 #include "MarbleDebug.h"
 
-#include "KmlElementDictionary.h"
 #include "GeoDataData.h"
 #include "GeoDataSimpleArrayData.h"
 #include "GeoParser.h"
+#include "KmlElementDictionary.h"
 
 #include <QVariant>
 
@@ -18,21 +18,21 @@ namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( value )
-KML_DEFINE_TAG_HANDLER_GX22( value )
+KML_DEFINE_TAG_HANDLER(value)
+KML_DEFINE_TAG_HANDLER_GX22(value)
 
-GeoNode* KmlvalueTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlvalueTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_value)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_value)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if( parentItem.represents( kmlTag_Data ) ) {
+    if (parentItem.represents(kmlTag_Data)) {
         QString value = parser.readElementText().trimmed();
-        parentItem.nodeAs<GeoDataData>()->setValue( QVariant( value ) );
-    } else if( parentItem.represents( kmlTag_SimpleArrayData ) ) {
+        parentItem.nodeAs<GeoDataData>()->setValue(QVariant(value));
+    } else if (parentItem.represents(kmlTag_SimpleArrayData)) {
         QString value = parser.readElementText().trimmed();
-        parentItem.nodeAs<GeoDataSimpleArrayData>()->append( QVariant( value ) );
+        parentItem.nodeAs<GeoDataSimpleArrayData>()->append(QVariant(value));
     }
     return nullptr;
 }
