@@ -14,15 +14,15 @@ namespace Marble
 namespace kml
 {
 
-KML_DEFINE_TAG_HANDLER( viewBoundScale )
+KML_DEFINE_TAG_HANDLER(viewBoundScale)
 
-GeoNode *KmlviewBoundScaleTagHandler::parse(GeoParser & parser) const
+GeoNode *KmlviewBoundScaleTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT ( parser.isStartElement() && parser.isValidElement( kmlTag_viewBoundScale ) );
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QString::fromLatin1(kmlTag_viewBoundScale)));
     GeoStackItem parentItem = parser.parentElement();
-    if ( parentItem.is<GeoDataLink>() ){
+    if (parentItem.is<GeoDataLink>()) {
         qreal const viewBoundScale = parser.readElementText().trimmed().toDouble();
-        parentItem.nodeAs<GeoDataLink>()->setViewBoundScale( viewBoundScale );
+        parentItem.nodeAs<GeoDataLink>()->setViewBoundScale(viewBoundScale);
     }
 
     return nullptr;
