@@ -10,16 +10,14 @@
 #define MARBLE_GEOSCENETILEDATASET_H
 
 #include <QList>
-#include <QVector>
 #include <QSize>
+#include <QStringList>
+#include <QUrl>
 
+#include "GeoDataLatLonBox.h"
 #include "GeoSceneAbstractDataset.h"
 #include "GeoSceneAbstractTileProjection.h"
 #include "MarbleGlobal.h"
-#include "GeoDataLatLonBox.h"
-
-class QStringList;
-class QUrl;
 
 /**
  * @short Tiled dataset stored in a layer. TextureTile and VectorTile layes inherit from this class.
@@ -38,60 +36,64 @@ class TileId;
 
 class GEODATA_EXPORT GeoSceneTileDataset : public GeoSceneAbstractDataset
 {
- public:
-    enum StorageLayout { Marble, OpenStreetMap, TileMapService };
+public:
+    enum StorageLayout {
+        Marble,
+        OpenStreetMap,
+        TileMapService
+    };
 
-    explicit GeoSceneTileDataset( const QString& name );
+    explicit GeoSceneTileDataset(const QString &name);
     ~GeoSceneTileDataset() override;
-    const char* nodeType() const override;
+    const char *nodeType() const override;
 
     QString sourceDir() const;
-    void setSourceDir( const QString& sourceDir );
+    void setSourceDir(const QString &sourceDir);
 
     QString installMap() const;
-    void setInstallMap( const QString& installMap );
+    void setInstallMap(const QString &installMap);
 
     StorageLayout storageLayout() const;
-    void setStorageLayout( const StorageLayout );
+    void setStorageLayout(const StorageLayout);
 
-    void setServerLayout( const ServerLayout * );
+    void setServerLayout(const ServerLayout *);
     const ServerLayout *serverLayout() const;
 
     int levelZeroColumns() const;
-    void setLevelZeroColumns( const int );
+    void setLevelZeroColumns(const int);
 
     int levelZeroRows() const;
-    void setLevelZeroRows( const int );
+    void setLevelZeroRows(const int);
 
     bool hasMaximumTileLevel() const;
     int maximumTileLevel() const;
-    void setMaximumTileLevel( const int );
+    void setMaximumTileLevel(const int);
 
     int minimumTileLevel() const;
     void setMinimumTileLevel(int level);
-    
-    void setTileLevels(const QString &tileLevels);
-    QVector<int> tileLevels() const;
 
-    QVector<QUrl> downloadUrls() const;
+    void setTileLevels(const QString &tileLevels);
+    QList<int> tileLevels() const;
+
+    QList<QUrl> downloadUrls() const;
 
     const QSize tileSize() const;
-    void setTileSize( const QSize &tileSize );
+    void setTileSize(const QSize &tileSize);
 
     /**
      * @brief set bounds for the texture. Tiles outside of these bounds won't be searched in this texture.
      * Null box means no bounds.
      */
-    void setLatLonBox( const GeoDataLatLonBox &box );
+    void setLatLonBox(const GeoDataLatLonBox &box);
     GeoDataLatLonBox latLonBox() const;
 
     void setTileProjection(GeoSceneAbstractTileProjection::Type projectionType);
 
-    const GeoSceneAbstractTileProjection * tileProjection() const;
+    const GeoSceneAbstractTileProjection *tileProjection() const;
     GeoSceneAbstractTileProjection::Type tileProjectionType() const;
 
     QString blending() const;
-    void setBlending( const QString &name );
+    void setBlending(const QString &name);
 
     /**
      * Creates a download URL for the given tile id.
@@ -99,18 +101,18 @@ class GEODATA_EXPORT GeoSceneTileDataset : public GeoSceneAbstractDataset
      * It implements the round robin for the tile servers.
      * On each invocation the next url is returned.
      */
-    QUrl downloadUrl( const TileId & ) const;
-    void addDownloadUrl( const QUrl & );
+    QUrl downloadUrl(const TileId &) const;
+    void addDownloadUrl(const QUrl &);
 
-    QString relativeTileFileName( const TileId & ) const;
+    QString relativeTileFileName(const TileId &) const;
 
     QString themeStr() const;
 
     QList<const DownloadPolicy *> downloadPolicies() const;
-    void addDownloadPolicy( const DownloadUsage usage, const int maximumConnections );
+    void addDownloadPolicy(const DownloadUsage usage, const int maximumConnections);
 
- private:
-    Q_DISABLE_COPY( GeoSceneTileDataset )
+private:
+    Q_DISABLE_COPY(GeoSceneTileDataset)
     QStringList hostNames() const;
 
     QString m_sourceDir;
@@ -121,17 +123,17 @@ class GEODATA_EXPORT GeoSceneTileDataset : public GeoSceneAbstractDataset
     int m_levelZeroRows;
     int m_minimumTileLevel;
     int m_maximumTileLevel;
-    QVector<int> m_tileLevels;
+    QList<int> m_tileLevels;
     mutable QSize m_tileSize;
     GeoDataLatLonBox m_latLonBox;
     GeoSceneAbstractTileProjection *m_tileProjection;
     QString m_blending;
 
     /// List of Urls which are used in a round robin fashion
-    QVector<QUrl> m_downloadUrls;
+    QList<QUrl> m_downloadUrls;
 
     /// Points to next Url for the round robin algorithm
-    mutable QVector<QUrl>::const_iterator m_nextUrl;
+    mutable QList<QUrl>::const_iterator m_nextUrl;
     QList<const DownloadPolicy *> m_downloadPolicies;
 };
 
@@ -145,7 +147,7 @@ inline QString GeoSceneTileDataset::blending() const
     return m_blending;
 }
 
-inline void GeoSceneTileDataset::setBlending( const QString &name )
+inline void GeoSceneTileDataset::setBlending(const QString &name)
 {
     m_blending = name;
 }
