@@ -8,10 +8,10 @@
 #ifndef MARBLE_GEOMETRYLAYER_H
 #define MARBLE_GEOMETRYLAYER_H
 
-#include <QObject>
-#include "LayerInterface.h"
 #include "GeoDataCoordinates.h"
 #include "GeoDataRelation.h"
+#include "LayerInterface.h"
+#include <QObject>
 
 class QAbstractItemModel;
 class QModelIndex;
@@ -37,17 +37,15 @@ public:
 
     QStringList renderPosition() const override;
 
-    bool render( GeoPainter *painter, ViewportParams *viewport,
-                         const QString& renderPos = QLatin1String("NONE"),
-                         GeoSceneLayer * layer = nullptr ) override;
+    bool render(GeoPainter *painter, ViewportParams *viewport, const QString &renderPos = QLatin1String("NONE"), GeoSceneLayer *layer = nullptr) override;
 
     RenderState renderState() const override;
 
     QString runtimeTrace() const override;
 
-    bool hasFeatureAt(const QPoint& curpos, const ViewportParams * viewport);
+    bool hasFeatureAt(const QPoint &curpos, const ViewportParams *viewport);
 
-    QVector<const GeoDataFeature*> whichFeatureAt( const QPoint& curpos, const ViewportParams * viewport );
+    QList<const GeoDataFeature *> whichFeatureAt(const QPoint &curpos, const ViewportParams *viewport);
 
     void highlightRouteRelation(qint64 osmId, bool enabled);
 
@@ -62,8 +60,8 @@ public:
     int debugLevelTag() const;
 
 public Q_SLOTS:
-    void addPlacemarks( const QModelIndex& index, int first, int last );
-    void removePlacemarks( const QModelIndex& index, int first, int last );
+    void addPlacemarks(const QModelIndex &index, int first, int last);
+    void removePlacemarks(const QModelIndex &index, int first, int last);
     void resetCacheData();
     void setTileLevel(int tileLevel);
 
@@ -76,7 +74,7 @@ public Q_SLOTS:
      * placemarks will be fletered out in GeoGraphicsScene
      * and will not be highlighted.
      */
-    void handleHighlight( qreal lon, qreal lat, GeoDataCoordinates::Unit unit );
+    void handleHighlight(qreal lon, qreal lat, GeoDataCoordinates::Unit unit);
 
 Q_SIGNALS:
     void repaintNeeded();
@@ -88,10 +86,10 @@ Q_SIGNALS:
      * in GeoGraphicsScene which will query for placemark->styleUrl()
      * to decide whether the placemark should be highlighted ot not.
      */
-    void highlightedPlacemarksChanged( const QVector<GeoDataPlacemark*>& clickedPlacemarks );
+    void highlightedPlacemarksChanged(const QList<GeoDataPlacemark *> &clickedPlacemarks);
 
 private:
-    GeometryLayerPrivate *d;
+    std::unique_ptr<GeometryLayerPrivate> d;
 };
 
 } // namespace Marble
