@@ -10,11 +10,9 @@
 
 #include "AccuracyLevel.h"
 
-
-
 namespace GeoCute
 {
-    
+
 enum ResourceFlags {
     ResourceNone = 0,
     ResourceNetwork = 1 << 0,
@@ -33,21 +31,18 @@ class PositionProvider;
 class MasterClient : public QObject
 {
     Q_OBJECT
-    
-    public:
-        explicit MasterClient(QObject* parent = 0);
-        ~MasterClient();
-        PositionProvider* positionProvider();
-        void setRequirements(AccuracyLevel, int min_time, SignallingFlags,
-            ResourceFlags);
-            
-    private:
-        class Private;
-        Private* const d;
+
+public:
+    explicit MasterClient(QObject *parent = 0);
+    ~MasterClient();
+    PositionProvider *positionProvider();
+    void setRequirements(AccuracyLevel, int min_time, SignallingFlags, ResourceFlags);
+
+private:
+    class Private;
+    Private *const d;
 };
 
 }
 
-
-
 #endif
