@@ -13,26 +13,25 @@
 #include "Planet.h"
 
 #include "GeoPainter.h"
-#include "ViewportParams.h"
 #include "MarbleModel.h"
+#include "ViewportParams.h"
 
 #include <QIcon>
 
 namespace Marble
 {
 
-AtmospherePlugin::AtmospherePlugin() :
-    RenderPlugin( nullptr ),
-    m_renderRadius(-1)
+AtmospherePlugin::AtmospherePlugin()
+    : RenderPlugin(nullptr)
+    , m_renderRadius(-1)
 {
 }
 
-AtmospherePlugin::AtmospherePlugin( const MarbleModel *marbleModel ) :
-    RenderPlugin( marbleModel ),
-    m_renderRadius(-1)
+AtmospherePlugin::AtmospherePlugin(const MarbleModel *marbleModel)
+    : RenderPlugin(marbleModel)
+    , m_renderRadius(-1)
 {
-    connect( marbleModel, SIGNAL(themeChanged(QString)),
-             this, SLOT(updateTheme()) );
+    connect(marbleModel, &MarbleModel::themeChanged, this, &AtmospherePlugin::updateTheme);
 }
 
 QStringList AtmospherePlugin::backendTypes() const
@@ -57,12 +56,12 @@ RenderPlugin::RenderType AtmospherePlugin::renderType() const
 
 QString AtmospherePlugin::name() const
 {
-    return tr( "Atmosphere" );
+    return tr("Atmosphere");
 }
 
 QString AtmospherePlugin::guiString() const
 {
-    return tr( "&Atmosphere" );
+    return tr("&Atmosphere");
 }
 
 QString AtmospherePlugin::nameId() const
@@ -77,7 +76,7 @@ QString AtmospherePlugin::version() const
 
 QString AtmospherePlugin::description() const
 {
-    return tr( "Shows the atmosphere around the earth." );
+    return tr("Shows the atmosphere around the earth.");
 }
 
 QIcon AtmospherePlugin::icon() const
@@ -90,15 +89,14 @@ QString AtmospherePlugin::copyrightYears() const
     return QStringLiteral("2006-2012");
 }
 
-QVector<PluginAuthor> AtmospherePlugin::pluginAuthors() const
+QList<PluginAuthor> AtmospherePlugin::pluginAuthors() const
 {
-    return QVector<PluginAuthor>()
-            << PluginAuthor(QStringLiteral("Torsten Rahn"), QStringLiteral("tackat@kde.org"))
-            << PluginAuthor(QStringLiteral("Inge Wallin"), QStringLiteral("ingwa@kde.org"))
-            << PluginAuthor(QStringLiteral("Jens-Michael Hoffmann"), QStringLiteral("jmho@c-xx.com"))
-            << PluginAuthor(QStringLiteral("Patrick Spendrin"), QStringLiteral("ps_ml@gmx.de"))
-            << PluginAuthor(QStringLiteral("Bernhard Beschow"), QStringLiteral("bbeschow@cs.tu-berlin.de"))
-            << PluginAuthor(QStringLiteral("Mohammed Nafees"), QStringLiteral("nafees.technocool@gmail.com"));
+    return QList<PluginAuthor>() << PluginAuthor(QStringLiteral("Torsten Rahn"), QStringLiteral("tackat@kde.org"))
+                                 << PluginAuthor(QStringLiteral("Inge Wallin"), QStringLiteral("ingwa@kde.org"))
+                                 << PluginAuthor(QStringLiteral("Jens-Michael Hoffmann"), QStringLiteral("jmho@c-xx.com"))
+                                 << PluginAuthor(QStringLiteral("Patrick Spendrin"), QStringLiteral("ps_ml@gmx.de"))
+                                 << PluginAuthor(QStringLiteral("Bernhard Beschow"), QStringLiteral("bbeschow@cs.tu-berlin.de"))
+                                 << PluginAuthor(QStringLiteral("Mohammed Nafees"), QStringLiteral("nafees.technocool@gmail.com"));
 }
 
 qreal AtmospherePlugin::zValue() const
@@ -119,61 +117,57 @@ bool AtmospherePlugin::isInitialized() const
 void AtmospherePlugin::updateTheme()
 {
     bool hasAtmosphere = marbleModel()->planet()->hasAtmosphere();
-    setEnabled( hasAtmosphere );
-    setVisible( hasAtmosphere );
+    setEnabled(hasAtmosphere);
+    setVisible(hasAtmosphere);
 }
 
-bool AtmospherePlugin::render( GeoPainter *painter,
-                              ViewportParams *viewParams,
-                              const QString &renderPos,
-                              GeoSceneLayer *layer )
+bool AtmospherePlugin::render(GeoPainter *painter, ViewportParams *viewParams, const QString &renderPos, GeoSceneLayer *layer)
 {
     Q_UNUSED(renderPos)
     Q_UNUSED(layer)
 
-    if ( !visible()  || !marbleModel()->planet()->hasAtmosphere() )
+    if (!visible() || !marbleModel()->planet()->hasAtmosphere())
         return true;
 
     // Only draw an atmosphere if projection is spherical
-    if ( viewParams->projection() != Spherical && viewParams->projection() != VerticalPerspective )
+    if (viewParams->projection() != Spherical && viewParams->projection() != VerticalPerspective)
         return true;
 
     // No use to draw atmosphere if it's not visible in the area.
-    if ( viewParams->mapCoversViewport() )
+    if (viewParams->mapCoversViewport())
         return true;
 
     // Gradient should be recalculated only if planet color or size changed
-    if(viewParams->radius() != m_renderRadius || marbleModel()->planet()->atmosphereColor() != m_renderColor) {
+    if (viewParams->radius() != m_renderRadius || marbleModel()->planet()->atmosphereColor() != m_renderColor) {
         m_renderRadius = viewParams->radius();
         m_renderColor = marbleModel()->planet()->atmosphereColor();
         repaintPixmap(viewParams);
     }
-    int  imageHalfWidth  = viewParams->width() / 2;
-    int  imageHalfHeight = viewParams->height() / 2;
-    painter->drawPixmap(imageHalfWidth  - (int) ( (qreal) ( viewParams->radius() ) * 1.05 ),
-                        imageHalfHeight - (int) ( (qreal) ( viewParams->radius() ) * 1.05 ),
+    int imageHalfWidth = viewParams->width() / 2;
+    int imageHalfHeight = viewParams->height() / 2;
+    painter->drawPixmap(imageHalfWidth - (int)((qreal)(viewParams->radius()) * 1.05),
+                        imageHalfHeight - (int)((qreal)(viewParams->radius()) * 1.05),
                         m_renderPixmap);
     return true;
 }
 
 void AtmospherePlugin::repaintPixmap(const ViewportParams *viewParams)
 {
-    int  imageHalfWidth  = 1.05 * viewParams->radius();
-    int  imageHalfHeight = 1.05 * viewParams->radius();
+    int imageHalfWidth = 1.05 * viewParams->radius();
+    int imageHalfHeight = 1.05 * viewParams->radius();
 
-    int diameter = (int) ( 2.1 * (qreal) ( viewParams->radius()));
+    int diameter = (int)(2.1 * (qreal)(viewParams->radius()));
     m_renderPixmap = QPixmap(diameter, diameter);
     m_renderPixmap.fill(QColor(Qt::transparent));
 
     QPainter renderPainter(&m_renderPixmap);
 
-    QColor color = marbleModel()->planet()->atmosphereColor();
+    const QColor color = marbleModel()->planet()->atmosphereColor();
 
     // Recalculate the atmosphere effect and paint it to canvasImage.
-    QRadialGradient grad( QPointF( imageHalfWidth, imageHalfHeight ),
-                           1.05 * viewParams->radius() );
-    grad.setColorAt( 0.91, color );
-    grad.setColorAt( 1.00, QColor(color.red(), color.green(), color.blue(), 0) );
+    QRadialGradient grad(QPointF(imageHalfWidth, imageHalfHeight), 1.05 * viewParams->radius());
+    grad.setColorAt(0.91, color);
+    grad.setColorAt(1.00, QColor(color.red(), color.green(), color.blue(), 0));
 
     QBrush brush(grad);
     renderPainter.setBrush(brush);
