@@ -13,9 +13,9 @@ namespace Marble
 class FoursquareModel : public AbstractDataPluginModel
 {
     Q_OBJECT
-    
+
 public:
-    explicit FoursquareModel( const MarbleModel *marbleModel, QObject *parent = nullptr );
+    explicit FoursquareModel(const MarbleModel *marbleModel, QObject *parent = nullptr);
     ~FoursquareModel() override;
 
 protected:
@@ -23,14 +23,13 @@ protected:
      * Generates the download url for the description file from the web service depending on
      * the @p box surrounding the view and the @p number of files to show.
      **/
-    void getAdditionalItems( const GeoDataLatLonAltBox& box,
-                                     qint32 number = 10 ) override;
+    void getAdditionalItems(const GeoDataLatLonAltBox &box, qint32 number = 10) override;
 
     /**
      * Parses the @p file which getAdditionalItems downloads and
      * prepares the data for usage.
      **/
-    void parseFile( const QByteArray& file ) override;
+    void parseFile(const QByteArray &file) override;
 };
 
 }
