@@ -15,7 +15,7 @@
 
 namespace Ui
 {
-    class WeatherConfigWidget;
+class WeatherConfigWidget;
 }
 
 namespace Marble
@@ -25,32 +25,32 @@ class WeatherPlugin : public AbstractDataPlugin, public DialogConfigurationInter
 {
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.kde.marble.WeatherPlugin")
-    Q_INTERFACES( Marble::RenderPluginInterface )
-    Q_INTERFACES( Marble::DialogConfigurationInterface )
-    MARBLE_PLUGIN( WeatherPlugin )
-    
- public:
+    Q_INTERFACES(Marble::RenderPluginInterface)
+    Q_INTERFACES(Marble::DialogConfigurationInterface)
+    MARBLE_PLUGIN(WeatherPlugin)
+
+public:
     WeatherPlugin();
 
-    explicit WeatherPlugin( const MarbleModel *marbleModel );
+    explicit WeatherPlugin(const MarbleModel *marbleModel);
 
     ~WeatherPlugin() override;
-    
+
     void initialize() override;
 
     QString name() const override;
-    
+
     QString guiString() const override;
 
     QString nameId() const override;
-    
+
     QString version() const override;
 
     QString description() const override;
 
     QString copyrightYears() const override;
 
-    QVector<PluginAuthor> pluginAuthors() const override;
+    QList<PluginAuthor> pluginAuthors() const override;
 
     QString aboutDataText() const override;
 
@@ -58,31 +58,31 @@ class WeatherPlugin : public AbstractDataPlugin, public DialogConfigurationInter
 
     QDialog *configDialog() override;
 
-    QHash<QString,QVariant> settings() const override;
+    QHash<QString, QVariant> settings() const override;
 
-    void setSettings( const QHash<QString,QVariant> &settings ) override;
+    void setSettings(const QHash<QString, QVariant> &settings) override;
 
 protected:
     bool eventFilter(QObject *object, QEvent *event) override;
 
- private Q_SLOTS:
+private Q_SLOTS:
     void readSettings();
     void writeSettings();
     void updateItemSettings();
-    void favoriteItemsChanged( const QStringList& favoriteItems ) override;
-    
- Q_SIGNALS:
+    void favoriteItemsChanged(const QStringList &favoriteItems) override;
+
+Q_SIGNALS:
     void changedSettings();
 
- private:
+private:
     void updateSettings();
 
     quint32 m_updateInterval;
     const QIcon m_icon;
-    QDialog * m_configDialog;
-    Ui::WeatherConfigWidget * ui_configWidget;
+    QDialog *m_configDialog;
+    Ui::WeatherConfigWidget *ui_configWidget;
 
-    QHash<QString,QVariant> m_settings;
+    QHash<QString, QVariant> m_settings;
 };
 
 }
