@@ -10,21 +10,21 @@
 namespace Marble
 {
 
-NominatimPlugin::NominatimPlugin( QObject *parent ) :
-    SearchRunnerPlugin( parent )
+NominatimPlugin::NominatimPlugin(QObject *parent)
+    : SearchRunnerPlugin(parent)
 {
     setSupportedCelestialBodies(QStringList(QStringLiteral("earth")));
-    setCanWorkOffline( false );
+    setCanWorkOffline(false);
 }
 
 QString NominatimPlugin::name() const
 {
-    return tr( "OpenStreetMap Nominatim Search" );
+    return tr("OpenStreetMap Nominatim Search");
 }
 
 QString NominatimPlugin::guiString() const
 {
-    return tr( "OpenStreetMap Nominatim" );
+    return tr("OpenStreetMap Nominatim");
 }
 
 QString NominatimPlugin::nameId() const
@@ -39,7 +39,7 @@ QString NominatimPlugin::version() const
 
 QString NominatimPlugin::description() const
 {
-    return tr( "Online search for placemarks using the OpenStreetMap Nominatim service" );
+    return tr("Online search for placemarks using the OpenStreetMap Nominatim service");
 }
 
 QString NominatimPlugin::copyrightYears() const
@@ -47,14 +47,13 @@ QString NominatimPlugin::copyrightYears() const
     return QStringLiteral("2010, 2012");
 }
 
-QVector<PluginAuthor> NominatimPlugin::pluginAuthors() const
+QList<PluginAuthor> NominatimPlugin::pluginAuthors() const
 {
-    return QVector<PluginAuthor>()
-            << PluginAuthor(QStringLiteral("Dennis Nienhüser"), QStringLiteral("nienhueser@kde.org"))
-            << PluginAuthor(QStringLiteral("Bernhard Beschow"), QStringLiteral("bbeschow@cs.tu-berlin.de"));
+    return QList<PluginAuthor>() << PluginAuthor(QStringLiteral("Dennis Nienhüser"), QStringLiteral("nienhueser@kde.org"))
+                                 << PluginAuthor(QStringLiteral("Bernhard Beschow"), QStringLiteral("bbeschow@cs.tu-berlin.de"));
 }
 
-SearchRunner* NominatimPlugin::newRunner() const
+SearchRunner *NominatimPlugin::newRunner() const
 {
     return new OsmNominatimRunner;
 }
